import { DatePipe, DecimalPipe } from '@angular/common';
import { ChangeDetectorRef, ElementRef, NgZone, OnDestroy, OnInit, PipeTransform, Renderer2, AfterViewInit, ViewContainerRef } from '@angular/core';
import { Subject } from 'rxjs';
import { IgxColumnComponent } from './column.component';
import { IgxDragDirective, IgxDropDirective } from '../directives/drag-drop/drag-drop.directive';
import { ConnectedPositioningStrategy } from '../services';
import { PositionSettings } from '../services/overlay/utilities';
import { IgxColumnResizingService } from './grid-column-resizing.service';
/**
 * @hidden
 */
export declare class IgxResizeHandleDirective implements AfterViewInit, OnDestroy {
    private zone;
    private element;
    colResizingService: IgxColumnResizingService;
    /**
     * @hidden
     */
    column: IgxColumnComponent;
    /**
     * @hidden
     */
    private _dblClick;
    /**
     * @hidden
     */
    private destroy$;
    constructor(zone: NgZone, element: ElementRef, colResizingService: IgxColumnResizingService);
    /**
     * @hidden
     */
    ngOnDestroy(): void;
    /**
     * @hidden
     */
    ngAfterViewInit(): void;
    /**
     * @hidden
     */
    onMouseOver(): void;
    /**
     * @hidden
     */
    onDoubleClick(): void;
    /**
     * @hidden
     */
    private _onResizeAreaMouseDown;
}
/**
 * @hidden
 */
export declare class IgxColumnResizerDirective implements OnInit, OnDestroy {
    element: ElementRef;
    document: any;
    zone: NgZone;
    restrictHResizeMin: number;
    restrictHResizeMax: number;
    resizeEnd: Subject<any>;
    resizeStart: Subject<any>;
    resize: Subject<any>;
    private _left;
    private _destroy;
    constructor(element: ElementRef, document: any, zone: NgZone);
    ngOnInit(): void;
    ngOnDestroy(): void;
    left: any;
    top: any;
    onMouseup(event: any): void;
    onMousedown(event: any): void;
    onMousemove(event: any): void;
}
/**
 * @hidden
 */
export declare class IgxColumnMovingService {
    private _icon;
    private _column;
    cancelDrop: boolean;
    isColumnMoving: boolean;
    column: IgxColumnComponent;
    icon: any;
}
/**
 * @hidden
 */
export declare enum DropPosition {
    BeforeDropTarget = 0,
    AfterDropTarget = 1,
    None = 2
}
/**
 * @hidden
 */
export declare class IgxColumnMovingDragDirective extends IgxDragDirective implements OnDestroy {
    private cms;
    data: any;
    readonly column: IgxColumnComponent;
    readonly draggable: boolean;
    readonly icon: HTMLElement;
    private subscription$;
    private _column;
    private _ghostClass;
    private ghostImgIconClass;
    private ghostImgIconGroupClass;
    constructor(_element: ElementRef, _viewContainer: ViewContainerRef, _zone: NgZone, _renderer: Renderer2, _cdr: ChangeDetectorRef, cms: IgxColumnMovingService);
    ngOnDestroy(): void;
    onEscape(event: any): void;
    onPointerDown(event: any): void;
    onPointerMove(event: any): void;
    onPointerUp(event: any): void;
    protected createGhost(pageX: any, pageY: any): void;
    private _unsubscribe;
}
/**
 * @hidden
 */
export declare class IgxColumnMovingDropDirective extends IgxDropDirective implements OnDestroy {
    private elementRef;
    private renderer;
    private zone;
    private cms;
    data: any;
    readonly column: IgxColumnComponent;
    readonly isDropTarget: boolean;
    readonly horizontalScroll: any;
    private _dropPos;
    private _dropIndicator;
    private _lastDropIndicator;
    private _column;
    private _hVirtDir;
    private _dragLeave;
    private _dropIndicatorClass;
    constructor(elementRef: ElementRef, renderer: Renderer2, zone: NgZone, cms: IgxColumnMovingService);
    ngOnDestroy(): void;
    onDragOver(event: any): void;
    onDragEnter(event: any): void;
    onDragLeave(event: any): void;
    onDragDrop(event: any): void;
}
export declare class IgxGridBodyDirective {
}
/**
 *@hidden
 */
export declare class IgxDatePipeComponent extends DatePipe implements PipeTransform {
    constructor(locale: string);
    transform(value: any, locale: string): string;
}
/**
 *@hidden
 */
export declare class IgxDecimalPipeComponent extends DecimalPipe implements PipeTransform {
    constructor(locale: string);
    transform(value: any, locale: string): string;
}
/**
 * @hidden
 */
export interface RowEditPositionSettings extends PositionSettings {
    container?: HTMLElement;
}
/**
 * @hidden
 */
export declare class RowEditPositionStrategy extends ConnectedPositioningStrategy {
    isTop: boolean;
    isTopInitialPosition: any;
    settings: RowEditPositionSettings;
    position(contentElement: HTMLElement, size: {
        width: number;
        height: number;
    }, document?: Document, initialCall?: boolean): void;
}
